@@ -11,6 +11,7 @@ extern void DEF_simplification		();
 extern void DEF_locale			();
 extern void DEF_printing		();
 extern void DEF_saving			();
+extern void DEF_data			();
 
 extern bool CHKBUT_fulls_isdef          ();
 extern bool RNDBUT_scrnsz_isdef         ();
@@ -26,6 +27,7 @@ extern bool CHKBUT_mirstamps_isdef      ();
 extern bool CHKBUT_allowprint_isdef     ();
 extern bool VALINP_printdel_isdef       ();
 extern bool CHKBUT_altsavedir_isdef     ();
+extern bool CHKBUT_altdatadir_isdef     ();
 
 extern void CB_SetActualTabToDefaults	  ();
 extern void CB_SetAllTabsToDefaults	    ();
